package FDN::Web::List;

use strict;
use Exporter;
our @ISA = ( 'Exporter' );
our @EXPORT = qw (
	__check_list
	__make_list
	$lists
);
our @EXPORT_OK = qw (
);
our %EXPORT_TAGS = qw (
);

use FDN::Common::Logger;
use FDN::Common::Modules;
use FDN::Web::Array;
use FDN::Web::TemplateParse qw ( parse );

our $debug = 1;
sub __debug($) {
	return if ! $debug;
	debug $_[0];
}

our $lists = {};

sub __check_list($) {
	my ( $list ) = @_;
	if ( ! defined $lists->{$list} ) {
		error "Undefined list <$list>";
		return 0;
	}
	my $info = $lists->{$list};
	my $ret = 1;
	if ( ! defined $info->{'fct'} ) {
		error "Poorly defined list: no 'fct' in list <$list>";
		$ret = 0;
	}
	if ( ! defined $info->{'title'} ) {
		error "Poorly defined list: no 'title' in list <$list>";
		$ret = 0;
	}
	if ( ! defined $info->{'rewrite-file'} ) {
		error "Poorly defined list: no 'rewrite-file' in list <$list>";
		$ret = 0;
	}
	if ( ! defined $info->{'rewrite-table'} ) {
		error "Poorly defined list: no 'rewrite-table' in list <$list>";
		$ret = 0;
	}
	if ( defined $info->{'sort'} && ! defined $info->{'url'} ) {
		error "Poorly defined list: cannot sort without 'url' in list <$list>";
		$ret = 0;
	}
	if ( defined $info->{'url'} && ! defined $info->{'sort'} ) {
		warning "Poorly defined list: 'url' is useless without 'sort' in list <$list>";
		$ret = 0;
	}
	return $ret;
}

sub __make_list($;$) {
	my ( $list, $sort ) = @_;
	if ( $debug && ! __check_list($list) ) {
		error "Badly defined list <$list>";
		return '';
	}
	my $info = $lists->{$list};
	my @lst = &{$info->{'fct'}}();
	if ( $info->{'sort'} ) {
		if ( $info->{'sort-default'} && ! defined $sort ) {
			$sort = $info->{'sort-default'};
			__debug "No sort order, using default";
		}
		if ( $info->{'sort-default'} && ! defined $info->{'sort'}->{$sort} ) {
			__debug "Invalid sort <$sort>, using default";
			$sort = $info->{'sort-default'};
		}
		if ( $sort ) {
			my $key = $info->{'sort'}->{$sort};
			__debug "Sorting according to <$sort>";
			@lst = sort $key @lst;
		} else {
			__debug "Not sorting";
		}
	}
	my $page;
	$page = tableau_2d($info->{'rewrite-file'},
			   $info->{'rewrite-table'},
			   \@lst,
			   $info->{'title'});
	if ( $info->{'url'} ) {
		$page = parse ( $page, { 'URL' => $info->{'url'} } );
	}
	return $page;
}

1;


