#!/usr/bin/perl -w

use Test::More tests => 7;
use FDN::Common::Config;

use strict;

$FDN::Common::Config::CONFIG_ROOT = './t/';

sub clean_tmp_files() {
    # n
    if ( -f 't/tmp.cfg' ) {
        system("rm -f t/tmp.cfg");
    }
    ok(! -f 't/tmp.cfg',	'Temporary config file correctly deleted');

    # n+1
    if ( -f 't/tmp.cfg.bin' ) {
        system("rm -f t/tmp.cfg.bin");
    }
    ok(! -f 't/tmp.cfg.bin',	'Temporary config (bin) file correctly deleted');
    
}

sub set_tmp_file($) {
    my ($text) = @_;
    open(F, ">t/tmp.cfg");
    print F $text;
    close F;
    # n
    ok(-f 't/tmp.cfg',		'Temporary config file correctly created');
}

my $file1 = 
	";\n".
	"[test]\n".
	"key = val\n".
	"\n".
	"[retest]\n".
	"rekey = reval\n";

my $file2 = 
	";\n".
	"[test]\n".
	"key = newval\n".
	"\n".
	"[retestnew]\n".
	"rekey = renewval\n";

my $cfg;
my $tmp;


# Take time to deprecate the .bin file
sleep(2);

# 1
ok(-f 't/tmp.cfg',		'Temporary file pre-exists');

# 2
ok(-f 't/tmp.cfg.bin',		'Temporary file (bin) pre-exists');

# 3
set_tmp_file($file2);

# 4
$tmp = Config_Key('test.cfg','SectionI','clef10');
is($tmp, 'newval',		'External reference refresh');

# 5
$cfg = Load_Config('tmp.cfg');
ok(defined $cfg,		'Temporary config file loaded');

# 6
is(ref $cfg, 'HASH',		'$cfg is a HASH reference');

# 7
is($cfg->{'test'}->{'key'}, 'newval',
				'Temporary file update detected');


#
# Just to make vim's color syntax engine know that this '.t' file is a Perl
# script :
#
# vim:se filetype=perl:
#
